<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Grafische Benutzeroberfläche, um verschiedene Optimierungen vorzunehmen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>Helligkeitsregler in der Systemleiste starten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>Öffnet sich bei geöffneter Anzeige-Registerkarte. Funktioniert nur mit der Xfce-Arbeitsoberfläche</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Öffnet die Themen-Registerkarte direkt.  Funktioniert mit der Xfce &amp; Fluxbox-Arbeitsoberfläche</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Öffnet die Andere-Registerkarte direkt. Funktioniert bei allen Arbeitsoberflächen</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Hauptfenster</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Helligkeit</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Hardware-Hintergrundhelligkeit</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="86"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="676"/>
        <location filename="../defaultlook.cpp" line="685"/>
        <location filename="../defaultlook.cpp" line="732"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <location filename="../defaultlook.cpp" line="767"/>
        <location filename="../defaultlook.cpp" line="770"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Leiste anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="51"/>
        <location filename="../defaultlook.ui" line="272"/>
        <source>Panel</source>
        <translation>Leiste</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fensterverhalten und Tastenkürzel anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="85"/>
        <source>Window Manager</source>
        <translation>Fensterverwaltung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Aussehen der Arbeitsoberfläche anpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="119"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="133"/>
        <source>Xfce Settings</source>
        <translation>Xfce-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="212"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="240"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>Leiste waagerecht anzeigen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Partition</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="300"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="307"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;wirksam für ALLE Leisten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <location filename="../defaultlook.ui" line="1811"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="332"/>
        <location filename="../defaultlook.ui" line="1821"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>Leiste senkrecht anzeigen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="362"/>
        <location filename="../defaultlook.ui" line="1800"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>Betrifft 1. Leiste</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel-Erweiterungs-Skalierung&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="389"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>Aktuelle Leistenkonfiguration sichern</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="399"/>
        <location filename="../defaultlook.ui" line="459"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="419"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Energiemanager</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="426"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>Gesicherte Leistenkonfiguration wiederhestellen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="449"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>Skalierung festlegen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <location filename="../defaultlook.ui" line="1816"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="484"/>
        <location filename="../defaultlook.ui" line="1826"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fensterknöpfe&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike ist die moderne Dock-Erweiterung für das Panel. Window Buttons ist die klassische Aufgabenliste ohne Dock-Funktionen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="536"/>
        <location filename="../defaultlook.ui" line="735"/>
        <location filename="../defaultlook.ui" line="909"/>
        <location filename="../defaultlook.ui" line="1077"/>
        <location filename="../defaultlook.ui" line="1084"/>
        <location filename="../defaultlook.ui" line="1091"/>
        <location filename="../defaultlook.ui" line="1158"/>
        <location filename="../defaultlook.ui" line="1303"/>
        <location filename="../defaultlook.ui" line="1852"/>
        <location filename="../defaultlook.ui" line="1911"/>
        <location filename="../defaultlook.ui" line="2083"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="556"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>Standardleiste wiederherstellen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>Tasklist-Erweiterung einrichten:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="580"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>Size</source>
        <extracomment>size of the mouse pointer or cursor</extracomment>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="679"/>
        <source>Theme Options</source>
        <translation>Themenoptionen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="595"/>
        <source>Remove User Theme Set</source>
        <translation>Theme Set entfernen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="695"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="606"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Einstellungen als Theme Set speichern</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="644"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Mauszeiger&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="664"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fensterverwaltung&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="702"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Programm&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="637"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Symbole&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="630"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="758"/>
        <location filename="../defaultlook.ui" line="769"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="776"/>
        <source>Transparency and shadow options</source>
        <translation>Transparenz- und Schattenoptionen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="875"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Bearbeite compton.conf direkt im Texteditor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="878"/>
        <source>Edit compton.conf</source>
        <translation>Bearbeite compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="889"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Einstellungen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="892"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="851"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Eine Änderung des VBlank Modus kann eventuell einige unangenehme Bildschirmprobleme lindern.  Unter der Hilfe gibt es mehr Informationen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="854"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="861"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Starte compton-conf Konfigurationswerkzeug</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="864"/>
        <source>Compton settings</source>
        <translation>Compton-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="796"/>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>default</source>
        <extracomment>default pointer size determined by X server</extracomment>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="801"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="815"/>
        <source>auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="820"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="825"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="830"/>
        <location filename="../defaultlook.ui" line="1416"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>Aus</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="932"/>
        <source>Display</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="943"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Hardware-Hintergrundhelligkeit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="950"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bildschirm Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="977"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Bildschirm für xrandr Tweaks auswählen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="987"/>
        <source>Resolution</source>
        <translation>Bildschirmauflösung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="994"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Abspeicherung geschieht per Bildschirm&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="997"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1004"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Software (xrandr) Helligkeit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1011"/>
        <location filename="../defaultlook.ui" line="1108"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1018"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>GTK Skalierung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1038"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>xrandr Skalierung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1134"/>
        <source>Config Options</source>
        <translation>Konfigurationsoptionen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1145"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Verkürzen langer Dateinamen auf der Arbeitsoberfläche abschalten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>Hinweis: Für den Ruhezustand wird SWAP &gt;= RAM benötigt.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1189"/>
        <source>Enable single-click on desktop</source>
        <translation>Einfach-Klick auf der Arbeitsoberfläche aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1196"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Ruhezustand im Log-Out Menü zulassen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1203"/>
        <location filename="../defaultlook.ui" line="1337"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Benutzerdefinierten Aktionen in Thunar auf die Systemvoreinstellungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1210"/>
        <location filename="../defaultlook.ui" line="1388"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Einfach-Klick in Thunar-Dateiverwaltung aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1217"/>
        <location filename="../defaultlook.ui" line="1649"/>
        <source>Thunar windows always open in split view</source>
        <translation>Thunar-Dateiverwaltungsfenster werden immer in der geteilten Ansicht geöffnet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1224"/>
        <location filename="../defaultlook.ui" line="1581"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Die geteilte Ansicht der Thunar-Dateiverwaltung öffnet sich horizontal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1231"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Prozentangaben, falls verfügbar, in Benachrichtigungen anzeigen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1238"/>
        <source>Enable Desktop Zoom </source>
        <translation>Zoom der Arbeitsoberfläche aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1245"/>
        <location filename="../defaultlook.ui" line="1767"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Zeige Fenster von allen Arbeitsbereichen in der Leiste</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1252"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>GTK-Dateidialog-Aktionsschaltflächen am unteren Rand der Dialoge anzeigen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1259"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>( schaltet auch programmspezifische Dekorationen für Xfce-Anwendungen aus)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1272"/>
        <source>Fluxbox</source>
        <translation>Fluxbox </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1284"/>
        <location filename="../defaultlook.ui" line="1624"/>
        <source>On</source>
        <translation>An</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1289"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1310"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1317"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Symbolleiste-Einstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1357"/>
        <source>Toggle icon captions</source>
        <translation>auf Bildunterschriften umschalten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1364"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Fluxbox-Menü zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1381"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1395"/>
        <source>Toggle desktop icons</source>
        <translation>Arbeitsoberflächen-Symbole wechseln</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1402"/>
        <location filename="../defaultlook.ui" line="1426"/>
        <source>Autohide</source>
        <translation>automatisch ausblenden</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1409"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock-Einstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1500"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Arbeitsoberflächen-Symbole&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1574"/>
        <source>Reset DefaultDock</source>
        <translation>auf Standard-Dock zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1588"/>
        <source>Manage Tint2 Panel</source>
        <translation>Tint2 Panel verwalten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1599"/>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1606"/>
        <location filename="../defaultlook.ui" line="1642"/>
        <location filename="../defaultlook.ui" line="1774"/>
        <source>Placement</source>
        <translation>Positionierung</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1613"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Bildschirmschoner&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1634"/>
        <source>On Hover</source>
        <translation>Beim Überfahren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1656"/>
        <location filename="../defaultlook.ui" line="1734"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;auf Standardeinstellungen zurücksetzen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1663"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Standardmenüeinträge, soweit vorhanden, zum bestehenden »fluxbox«-Menü hinzufügen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1666"/>
        <source>Upgrade existing menu entries</source>
        <translation>Vorhandene Menüeinträge aktualisieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1686"/>
        <source>Show Toolbar</source>
        <translation>Symbolleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1703"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>ALLE MX-Fluxbox Eintstellungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1710"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Wartezeit (in Minuten)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1723"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1839"/>
        <source>Workspace</source>
        <translation>Arbeitsbereich</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2101"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1781"/>
        <source>Enable single-click</source>
        <translation>Einfach-Klick aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1788"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>KDE/Plasma-Einstellungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1863"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1873"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Super-Taste</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1881"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Choose application&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Anwendung auswählen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1894"/>
        <source>Xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>Xfce-Super-Taste Standardeinstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1901"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Also known as the &amp;quot;windows&amp;quot; key&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Auch bekannt als &amp;quot;windows&amp;quot; Taste&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1904"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Mit Super (Meta)-Taste auszuführender Befehl</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1934"/>
        <source>Other</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2056"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Lightdm (Anmeldebildschirm) auf die Systemvorgaben zurücksetzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2015"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>Aktualisierungen von Liquorix-Kerneln anhalten oder aufheben</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2018"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Automatische Liquorix-Kernel-Aktualisierung aktivieren (MX-ahs-Paketquellen)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2032"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>Aktualisierungen von Debian-Kerneln anhalten oder aufheben</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2035"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Automatische Debian-Kernel-Aktualisierung aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1956"/>
        <source>Password for administrative tasks:</source>
        <translation>Passwort für administrative Aufgaben:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2070"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Einhängen von internen Laufwerken durch Benutzer ohne Administratorrechte aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1963"/>
        <source>Root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2001"/>
        <source>Enable kernel sandbox</source>
        <translation>Kernel-Sandbox aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1942"/>
        <source>&amp;User</source>
        <translation>&amp;Benutzer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1984"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Neustart erforderlich&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1987"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Bluetooth-Adapter beim Systemstart aktivieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1994"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>apt installiert zusätzliche &quot;empfohlene&quot; Pakete als Abhängigkeiten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2042"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Nach Installation, Entfernen und Aktualisierung von Paketen ein Fluxbox-All Aps-Menü generieren</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1970"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Programmeigene Gestaltung der Oberfläche von »GTK3«-Programmen (»CSD«) verwenden, wenn diese es unterstützen. (erfordert Sitzungsneustart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2025"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Intel-Treiber anstelle des standardmäßigen &quot;modsetting&quot; Treibers verwenden (Neustart erforderlich)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1977"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-intel.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1949"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Option &quot;Tearfree&quot; des AMDGPU-Treibers benutzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2063"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-amd.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2049"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Option &quot;Tearfree&quot; des Radeon-Treibers benutzen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2008"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ANMERKUNG: Die existierende Datei /etc/X11/xorg.conf.d/20-radeon.conf wird zur Sicherung in den &lt;HOME&gt;-Ordner verschoben </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--Anzeige-Umschaltung nur gültig für Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="656"/>
        <source>About MX Tweak</source>
        <translation>Über MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="659"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Anwendung für schnelle Änderungen und Anpassungen an den Voreinstellungen des UI-Themas</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="662"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="676"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="686"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Fertig! Die Änderungen werden nach einem Neustart von Firefox wirksam.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="733"/>
        <source>Plese remove special characters</source>
        <translation>Sonderzeichen bitte entfernen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="733"/>
        <source>from file name</source>
        <translation>Aus Dateinamen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Der Dateiname existiert bereits. Wählen Sie einen anderen Namen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="768"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Die Datei ist keine gültige tar.xz Archivdatei</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="771"/>
        <source>Archive does not contain a panel config</source>
        <translation>Das Archiv enthält keine Panel-Konfiguration</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="946"/>
        <source>Panel settings</source>
        <translation>Leisten-Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="947"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Die aktuellen Panel-Einstellungen wurden im versteckten Ordner .restore im Home-Ordner gesichert (~/.restore/).</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1838"/>
        <source>settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2178"/>
        <source>Choose a theme set</source>
        <translation>Wählen Sie ein Thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2584"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Bitte eine Bezeichnung für den Computer eingeben.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2588"/>
        <source>Sorry, your computer name contains invalid characters.
You&apos;ll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Der Computername enthält leider ungültige Zeichen. 
Bitte wählen Sie einen anderen Namen, 
bevor Sie fortfahren.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="4146"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Die zu startende Anwendung auswählen</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Theme Set entfernen</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Neues Theme Set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Namen für das neue Theme Set eingeben</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Fensterknöpfe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aussehen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Knopfbeschriftungen anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Flache Knöpfe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Griff anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sortierreihenfolge:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Zeitstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Titel und Zeitstempel gruppieren</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titel und Fenstertitel gruppieren</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Keine, ziehen und ablegen ermöglichen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Verhalten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Fenstergruppierung:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Immer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Mittelklickaktion:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Fenster schließen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Fenster verkleinern</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Verkleinerte Fenster in aktuellem Arbeitsbereich wiederherstellen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Fensterrahmen zeichnen, wenn ein Knopf mit der Maus überfahren wird</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Fenster mit dem Mausrad wechseln</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtern&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Fenster aller Arbeits- oder Anzeigenbereiche anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Nur verkleinerte Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Fenster von allen Bildschirmen anzeigen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Popup-Fenster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Fenster während des Verschiebens</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Deckkraft-Einstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Fensterrahmen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Zeige Schatten unter Dockfenstern</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Zeige Schatten unter Popup-Fenstern</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Fenster während der Größenänderung</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Zeige Schatten unter gewöhnlichen Fenstern</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Funktionseinstellungen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Zeige beim Durchlauf Fenstervorschauen anstatt Symbole</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Vollbildüberlagerungsfenster sofort anzeigen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Inaktive Fenster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Zeichnen mit der vertikalen Austastlücke synchronisieren</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Einstellungen</translation>
    </message>
</context>
</TS>
